# Koine::DbBkp

Backup for Databases

- MySQL (with rake task)
- MySQL on Rails (with rake task)

[![Build Status](https://travis-ci.org/mjacobus/koine-db_bkp.svg?branch=master)](https://travis-ci.org/mjacobus/koine-db_bkp)
[![Coverage Status](https://coveralls.io/repos/github/mjacobus/koine-db_bkp/badge.svg?branch=master)](https://coveralls.io/github/mjacobus/koine-db_bkp?branch=master)
[![Code Climate](https://codeclimate.com/github/mjacobus/koine-db_bkp/badges/gpa.svg)](https://codeclimate.com/github/mjacobus/koine-db_bkp)
[![Issue Count](https://codeclimate.com/github/mjacobus/koine-db_bkp/badges/issue_count.svg)](https://codeclimate.com/github/mjacobus/koine-db_bkp)
[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/mjacobus/koine-db_bkp/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/mjacobus/koine-db_bkp/?branch=master)

[![Dependency Status](https://gemnasium.com/badges/github.com/mjacobus/koine-db_bkp.svg)](https://gemnasium.com/github.com/mjacobus/koine-db_bkp)
[![Gem Version](https://badge.fury.io/rb/koine-db_bkp.svg)](https://badge.fury.io/rb/koine-db_bkp)

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'koine-db_bkp'
```

## Usage

### MySql

```ruby
require 'koine/db_bkp/mysql/dump'

backup = Koine::DbBkp::Mysql::Dump.new(
  hostname: 'host',
  database: 'db',
  username: 'username',
  password: 'password',
)

backup.to_sql_file('/bkp/file.sql')
```

### Rake tasks

```ruby
# Rakefile

require "koine/db_bkp"

Koine::Tasks::MysqlDump.new do |t|
  t.task_name    = 'some_task'     # defaults to 'mysql:dump'
  t.output_file  = 'backup_{timestamp}.sql' # defaults to ENV['MYSQL_BACKUP_FILE']
                                            # {timestamp} is a placeholder for the autogenerated timestamp

  # database config
  t.url          = 'mysql2://username:password@hostname/database_name' # defaults to ENV['DB_URL']

  # or database config
  t.hostname     = 'hostname'      # defaults to ENV['DB_HOST']
  t.database     = 'database_name' # defaults to ENV['DB_NAME']
  t.username     = 'username'      # defaults to ENV['DB_USER']
  t.password     = 'password'      # defaults to ENV['DB_PASSWORD']

  # rake task dependencies
  t.dependencies = [:environment] # defaults to []
end
```

#### Rails task

```ruby
# Rakefile

require "koine/db_bkp"

# same options of Koine::Tasks::RailsMysqlDump apply
Koine::Tasks::RailsMysqlDump.new
```

```bash
rake rake mysql:dump
```

```bash
# database config will be taken from the Rails.configuration.database_configuration[ENV['RAILS_ENV']]

export MYSQL_BACKUP_FILE='/foo/bar_{timestamp}.sql'

rake mysql:rails_dump
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/mjacobus/koine-db_bkp. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.


## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

